@@ -3,6 +3,10 @@ import haml
 
 from bottle import template, DEBUG, BaseTemplate
 
+# Use two spaces for indention in generated HTML
+# code instead of \t
+haml.codegen.Generator.indent_str = "  "
+
 
 class HamlTemplate(BaseTemplate):
 
@@ -16,7 +20,7 @@ class HamlTemplate(BaseTemplate):
         options.setdefault('format_exceptions', bool(DEBUG))
         lookup = TemplateLookup(directories=self.lookup, **options)
         options['preprocessor'] = haml.preprocessor
-        
+
         if self.source:
             self.tpl = Template(self.source, lookup=lookup, **options)
         else:
